@@ -54,6 +54,7 @@ import com.extjs.gxt.ui.client.widget.button.Button;
 import com.extjs.gxt.ui.client.widget.layout.BorderLayout;
 import com.extjs.gxt.ui.client.widget.layout.BorderLayoutData;
 import com.extjs.gxt.ui.client.widget.menu.Menu;
+import com.extjs.gxt.ui.client.widget.menu.MenuItem;
 import com.extjs.gxt.ui.client.widget.toolbar.FillToolItem;
 import com.extjs.gxt.ui.client.widget.toolbar.SeparatorToolItem;
 import com.extjs.gxt.ui.client.widget.toolbar.ToolBar;
@@ -74,9 +75,6 @@ import com.google.web.bindery.event.shared.SimpleEventBus;
  */
 public class TemplatePanelActionEdit {
 
-	/**
-	 * 
-	 */
 	public static final String DEFINITION_AND_VALIDATION_POST_OPERATIONS = "> Definition and Validation Post Operations";
 	private int numColumns;
 	private FlexTable flexTableTemplate = new FlexTable();
@@ -110,6 +108,11 @@ public class TemplatePanelActionEdit {
 	private Button createTimeDimensionButton;
 	private ZIndexReference zIndexReference;
 	private Button normalizeButton;
+	private MenuItem createMultiColumnRule;
+	private MenuItem removeMultiColumnRule;
+//	private MultiColumnRuleMng multiColumnRuleMng;
+	private Button addMultiColumnRule;
+	private ArrayList<TemplateExpression> listTableRules;
 	
 		/**
 		 * Instantiates a new template panel action updater.
@@ -177,8 +180,6 @@ public class TemplatePanelActionEdit {
 
 		this.tableContainer.setHeaderVisible(false);
 		this.tableContainer.setBorders(false);
-//		this.tableContainer.setLayout(new FitLayout());
-//		this.tableContainer.setStyleAttribute("margin-top", "50px");
 		inizializeTableTemplate();
 		inizializeToolBar();
 	
@@ -525,8 +526,8 @@ public class TemplatePanelActionEdit {
 			}*/
 			
 			//HAS A REFERENCE?
-			if(tdDataType.getReference()!=null){
-				TdTFormatReference format = tdDataType.getReference();
+			if(tdDataType.getFormatReference()!=null){
+				TdTFormatReference format = tdDataType.getFormatReference();
 //				colTypeDialogMng.getScbDataTypeFormat().setValue(format);
 				columnDefinition.append("["+format.getId()+"]");
 				columnDefinition.append("<br/>");
@@ -709,6 +710,38 @@ public class TemplatePanelActionEdit {
 			}
 		});
 		
+//		addMultiColumnRule = new SplitButton("Table Rule");
+//		addMultiColumnRule.setTitle("Add a multi-column rule");
+//		addMultiColumnRule.setIcon(TdTemplateAbstractResources.ruleTableAdd());
+//		addMultiColumnRule.setScale(ButtonScale.MEDIUM);
+//		addMultiColumnRule.setIconAlign(IconAlign.TOP);
+//		addMultiColumnRule.setMenu(createAddMultiColumnRuleListener());
+//		
+//		addMultiColumnRule.addSelectionListener(new SelectionListener<ButtonEvent>() {
+//
+//			@Override
+//			public void componentSelected(ButtonEvent ce) {
+//				addMultiColumnRule.getMenu().show(addMultiColumnRule);
+//			}
+//		});
+		
+		
+		addMultiColumnRule = new Button(TdTemplateConstants.TABLE_RULE);
+		addMultiColumnRule.setTitle(TdTemplateConstants.ADD_A_MULTI_COLUMN_RULE);
+		addMultiColumnRule.setIcon(TdTemplateAbstractResources.ruleTableAdd());
+		addMultiColumnRule.setScale(ButtonScale.MEDIUM);
+		addMultiColumnRule.setIconAlign(IconAlign.TOP);
+
+		addMultiColumnRule.addSelectionListener(new SelectionListener<ButtonEvent>() {
+
+			@Override
+			public void componentSelected(ButtonEvent ce) {
+				
+				final MultiColumnRuleAction multiColumnRuleMng = new MultiColumnRuleAction(allColumns, actionControlleEventBus);
+				multiColumnRuleMng.getMultiExpressionDialog().show();
+			}
+		});
+
 		toolbar.add(addColumnButton);
 		toolbar.add(removeColumnButton);
 		toolbar.add(new SeparatorToolItem());
@@ -716,13 +749,67 @@ public class TemplatePanelActionEdit {
 		toolbar.add(aggregateByTimeButton);
 		toolbar.add(new SeparatorToolItem());
 		toolbar.add(normalizeButton);
-		
-		toolbar.add(new FillToolItem());
-		toolbar.add(undoLastOperation);
+		toolbar.add(addMultiColumnRule);
 		toolbar.add(new SeparatorToolItem());
+		toolbar.add(new FillToolItem());
+		toolbar.add(new SeparatorToolItem());
+		toolbar.add(undoLastOperation);
 		toolbar.add(historyActionsButton);
 		tableContainer.setTopComponent(toolbar);
 	}
+//	
+//	/**
+//	 * Creates the flow menu and listener.
+//	 *
+//	 * @return the menu
+//	 */
+//	private Menu createAddMultiColumnRuleListener() {
+//		  
+//	    Menu menu = new Menu();
+//
+//	    listTableRules = new ArrayList<TemplateExpression>();
+//	    
+//	    createMultiColumnRule = new MenuItem("Create");
+//	    createMultiColumnRule.setTitle("Create Multi-Column Rule");
+//	    createMultiColumnRule.setIcon(TdTemplateAbstractResources.pencil());
+//	    createMultiColumnRule.addSelectionListener(new SelectionListener<MenuEvent>() {
+//
+//			@Override
+//			public void componentSelected(MenuEvent ce) {
+//				GWT.log("Columns size is: "+allColumns.size());
+//				final MultiColumnRuleMng multiColumnRuleMng = new MultiColumnRuleMng(allColumns, actionControlleEventBus);
+//				Command cmd = new Command() {
+//						
+//						@Override
+//					public void execute() {
+//						TemplateExpression templateExpression = multiColumnRuleMng.getTemplateExpression();
+//						listTableRules.add(templateExpression);
+//					}
+//				};
+//					
+//			
+//				multiColumnRuleMng.getMultiExpressionDialog().show();
+//			}
+//	    });
+//
+////	    removeMultiColumnRule = new MenuItem("Remove");
+////	    removeMultiColumnRule.setTitle("Remove a multi-column rule");
+////	    removeMultiColumnRule.setIcon(TdTemplateAbstractResources.close());
+////	    removeMultiColumnRule.addSelectionListener(new SelectionListener<MenuEvent>() {
+////
+////			@Override
+////			public void componentSelected(MenuEvent ce) {
+////				multiColumnRuleMng = null;
+////			}
+////	    });
+////	    
+////	    removeMultiColumnRule.setVisible(false);
+//	    
+//	    menu.add(createMultiColumnRule);
+//	    menu.add(removeMultiColumnRule);
+//	 
+//	    return menu;  
+//	}  
 	
 	/**
 	 * Enable undo last operation.
@@ -766,4 +853,5 @@ public class TemplatePanelActionEdit {
 	public void resetrefreshSuggestion() {
 		refreshSuggestion(TdTemplateConstants.SUGGESTION, TdTemplateConstants.DO_YOU_WANT_ADD_POST_ACTIONS);
 	}
+
 }
